#!/bin/bash
#
# 
# DISCLAIMER
#   Trigo Technologies, Inc. disclaims all warranties or representations herein,
#   whether express, implied or statutory, to the fullest extent
#   permissible by law, including the implied warranties of title,
#   fitness for a particular purpose and merchantability.
# 
# COPYRIGHTS
#   Copyright 2001, 2002 Trigo Technologies, Inc. All rights reserved.
# 
#   Trigo Technologies, Inc.
#   8000 Marina Blvd, Suite 810
#   Brisbane, CA 94005
#   U.S.A.
#   www.trigo.com
# 
# TRADEMARKS
#   Trigo, Trigo Enterprise, Trigo Content Suite, Trigo Commerce Suite,
#   and Trigo Platform are trademarks of Trigo Technologies, Inc.
#   All other company and product names are trademarks or registered
#   trademarks of their respective owners.
#

#
# parses the argument list
# when it finds a --var=name
# it creates a variable _TRIGO_{VAR} and sets its value to {NAME}
# note that the created variable is in uppercase.
# in your shell script, use:
# . $TOP/bin/get_params.sh
#
# ex: get_params.sh --confirm_db=yes --name=acme
#     sets 2 variables: _TRIGO_CONFIRM_DB=yes, _TRIGO_NAME=acme
# use --debug=yes to see some debugging info

for _VAR in "$@"; do
    case ${_VAR} in
        --*=* )
            _VALUE=`${ECHO} ${_VAR}|cut -f2 -d "="`
            _NAME=`${ECHO} ${_VAR}|cut -f1 -d "="|cut -f3 -d "-"|${TR} a-z A-Z`
            _NEW_NAME="_TRIGO_${_NAME}"

            # do not assign value twice (debug mode looks nicer with nested calls :-)
            if [ ! "`eval ${ECHO} \\$${_NEW_NAME}`" = "${_VALUE}" ]; then
                if [ "${_TRIGO_DEBUG}" = "yes" ]; then
                    ${ECHO} "[setting ${_NEW_NAME}=${_VALUE}]"
                fi
                eval "${_NEW_NAME}=\"${_VALUE}\""
            fi
            ;;
    esac
done
