#!/bin/bash
# 
# DISCLAIMER
#   Trigo Technologies, Inc. disclaims all warranties or representations herein,
#   whether express, implied or statutory, to the fullest extent
#   permissible by law, including the implied warranties of title,
#   fitness for a particular purpose and merchantability.
# 
# COPYRIGHTS
#   Copyright 2001, 2002 Trigo Technologies, Inc. All rights reserved.
# 
#   Trigo Technologies, Inc.
#   8000 Marina Blvd, Suite 810
#   Brisbane, CA 94005
#   U.S.A.
#   www.trigo.com
# 
# TRADEMARKS
#   Trigo, Trigo Enterprise, Trigo Content Suite, Trigo Commerce Suite,
#   and Trigo Platform are trademarks of Trigo Technologies, Inc.
#   All other company and product names are trademarks or registered
#   trademarks of their respective owners.
#


#steps involved
# - load specs
# - load maps
# - load scripts
# - create workflows
# - load lookup tables [optional]
# - create selections

. ${TOP}/bin/get_params.sh

#----------------------------------------
#
# usage
#
#----------------------------------------

if [ "${_TRIGO_CODE}" = "" ]; then
    ${ECHO} "Usage: $0 --code=<acmeCode> [--name=<acmeName> --confirm_db=no]"
    exit
fi

#----------------------------------------
#
# get company id
#
#----------------------------------------

ACME_CODE=${_TRIGO_CODE}
ACME_NAME=${_TRIGO_NAME}
if [ -z "$ACME_NAME" ]; then
    export ACME_NAME=$ACME_CODE
fi

$DB_DIR/cmp/create_cmp.sh --code="${ACME_CODE}" --name="${ACME_NAME}"

#----------------------------------------
#
# init vars
#
#----------------------------------------

ACME_DIR=$DB_DIR/acme
ACME_TMP_DIR=$ACME_DIR/tmp

${RM} $ACME_TMP_DIR

#----------------------------------------
#
# specs
#
#----------------------------------------

${ECHO}
${ECHO} ====================================================
${ECHO} Creating specs for $ACME_CODE
${ECHO} ====================================================
${ECHO}

${MKDIR} $ACME_TMP_DIR/specs
cd $DB_ROOT_DIR/specs/acme

for file in `ls *.xml`; do
    ${ECHO} "  $file"
    cat $file \
        | ${SED} "s/%ACME_CODE%/$ACME_CODE/g" \
        | ${SED} "s/%ACME_NAME%/$ACME_NAME/g" \
        > $ACME_TMP_DIR/specs/$file
done

#----------------------------------------
#
# maps
#
#----------------------------------------

${ECHO}
${ECHO} ====================================================
${ECHO} Creating maps for $ACME_CODE
${ECHO} ====================================================
${ECHO}

${MKDIR} $ACME_TMP_DIR/maps
cd $DB_ROOT_DIR/maps/acme

for file in `ls *.xml`; do
    ${ECHO} "  $file"
    cat $file \
        | ${SED} "s/%ACME_CODE%/$ACME_CODE/g" \
        | ${SED} "s/%ACME_NAME%/$ACME_NAME/g" \
        > $ACME_TMP_DIR/maps/$file
done

BASIC_SCRIPT_SRC_FILE=${ACME_DIR}/acme_security.script
BASIC_SCRIPT_FILE=${ACME_DIR}/acme_security.script.tmp

${CAT} ${BASIC_SCRIPT_SRC_FILE} \
    | ${SED} "s/%ACME_CODE%/$ACME_CODE/g" \
    | ${SED} "s/%ACME_NAME%/$ACME_NAME/g" \
    > ${BASIC_SCRIPT_FILE}

${ECHO}
${ECHO} ====================================================
${ECHO} Setting up additional users for $ACME_CODE
${ECHO} ====================================================
${ECHO}
${JAVA_RT} austin.interpreter.test.TestScript --companycode="$ACME_CODE" \
                                              --username="trigo_root" \
                                              --scriptpath="${BASIC_SCRIPT_FILE}"

${RM} ${BASIC_SCRIPT_FILE}

${ECHO}
${ECHO} ====================================================
${ECHO} Inserting specs for $ACME_CODE
${ECHO} ====================================================
${ECHO}
#
#this needs the `ls *.xml` because specs need to be inserted in order, parent before child
#
cd ${TOP}/src/db/schema/acme/tmp/specs
$JAVA_RT_NOOUT trigo_content.impexp.DatabaseUploader -action=i -debug=n `ls *.xml`

${ECHO}
${ECHO} ====================================================
${ECHO} Loading po.xsd specs for $ACME_CODE
${ECHO} ====================================================
${ECHO}
${ECHO} "Do not worry about the message:"
${ECHO} "  Cannot find the declaration of element 'trigoDummyElement'"
${ECHO}

cd $DB_ROOT_DIR/specs/acme
$JAVA_RT_NOOUT trigo_content.impexp.SpecXSDBridge -company_code="${ACME_CODE}" \
                                                  -file_name="po.xsd" \
                                                  -spec_name="PO_XSD_PRIMARY_SPEC" \
                                                  -spec_type=PRIMARY_SPEC \
                                                  -primary_key_path="PO_XSD_PRIMARY_SPEC/PONumber" \
                                                  -max_ancestors=5 \
                                                  -top_level_name="purchaseOrder"

$JAVA_RT_NOOUT trigo_content.impexp.SpecXSDBridge -company_code="${ACME_CODE}" \
                                                  -file_name="po.xsd" \
                                                  -file_type=X \
                                                  -spec_name="PO_XSD_FILE_SPEC" \
                                                  -spec_type=FILE_SPEC \
                                                  -max_ancestors=5 \
                                                  -top_level_name="purchaseOrder"

$JAVA_RT_NOOUT trigo_content.impexp.SpecXSDBridge -company_code="${ACME_CODE}" \
                                                  -file_name="po.xsd" \
                                                  -file_type=X \
                                                  -spec_name="PO_XSD_MKT_SPEC" \
                                                  -spec_type=MKT_SPEC \
                                                  -max_ancestors=5 \
                                                  -top_level_name="purchaseOrder"

${ECHO}
${ECHO} ====================================================
${ECHO} Mapping specs for $ACME_CODE
${ECHO} ====================================================
${ECHO}
#this needs the `ls *.xml` because specs need to be inserted in order, parent before child
#
cd ${TOP}/src/db/schema/acme/tmp/maps
$JAVA_RT_NOOUT trigo_content.impexp.DatabaseUploader -action=i -debug=n `ls *.xml`

${ECHO}
${ECHO} ====================================================
${ECHO} Loading scripts for $ACME_CODE
${ECHO} ====================================================
${ECHO}

$JAVA_RT_NOOUT trigo_docstore.util.DocLoader -companycode=$ACME_CODE -username=jwilson -xmlfile=${SCRIPTS_DIR}/acme/acme_scripts.xml -encoding=Cp1252

#$JAVA_RT_NOOUT trigo_docstore.util.DocLoader -companycode=$ACME_CODE -username=jwilson -xmlfile=${DB_ROOT_DIR}/lkp/common/common_lkp.xml -encoding=Cp1252
#$JAVA_RT_NOOUT trigo_docstore.util.DocLoader -companycode=$ACME_CODE -username=jwilson -xmlfile=${DB_ROOT_DIR}/lkp/acme/acme_lkp.xml -encoding=Cp1252

${ECHO}
${ECHO} ====================================================
${ECHO} Populating consoles for $ACME_CODE
${ECHO} ====================================================
${ECHO}

cd $ACME_DIR
./acme_create_distributions.sh ${ACME_CODE}
./acme_create_feeds.sh ${ACME_CODE}

${ECHO}
${ECHO} ====================================================
${ECHO} Loading files for $ACME_CODE
${ECHO} ====================================================
${ECHO}

${RM} $TOP/public_html/suppliers/$ACME_CODE/aggregated_files
$JAVA_RT_NOOUT trigo_docstore.util.DocLoader -companycode=$ACME_CODE -username=jwilson -xmlfile=${ACME_DIR}/acme_ctg_load.xml
./acme_create_syns.sh ${ACME_CODE}


# ${ECHO} ====================================================
# ${ECHO} loading widgets for ${ACME_CODE}
# ${ECHO} ====================================================
# ${TOP}/bin/loadwidgets.sh ${ACME_CODE}

#${TOP}/src/db/schema/util/create_default_org.sh ${ACME_CODE}



cd $ACME_DIR
./acme_create_workflows.sh ${ACME_CODE}




if [ "${_TRIGO_LOAD_LKP}" = "yes" ]; then
	${ECHO}
	${ECHO} ====================================================
	${ECHO} Loading lookup tables for $ACME_CODE
	${ECHO} ====================================================
	${ECHO}

    cd $ACME_DIR
    ./loadlkps.sh $ACME_CODE jwilson '/lkp/common'
    ./loadlkps.sh $ACME_CODE jwilson '/lkp/acme'
fi

#${ECHO}
#${ECHO} ====================================================
#${ECHO} Inserting selections for testing security for $ACME_CODE
#${ECHO} ====================================================
#${ECHO}
#. ${TOP}/src/db/schema/regression/4.2/security/test_setup.sh

${RM} $OUTPUT_FILE
