#!/bin/bash
# 
# DISCLAIMER
#   Trigo Technologies, Inc. disclaims all warranties or representations herein,
#   whether express, implied or statutory, to the fullest extent
#   permissible by law, including the implied warranties of title,
#   fitness for a particular purpose and merchantability.
# 
# COPYRIGHTS
#   Copyright 2001, 2002 Trigo Technologies, Inc. All rights reserved.
# 
#   Trigo Technologies, Inc.
#   8000 Marina Blvd, Suite 810
#   Brisbane, CA 94005
#   U.S.A.
#   www.trigo.com
# 
# TRADEMARKS
#   Trigo, Trigo Enterprise, Trigo Content Suite, Trigo Commerce Suite,
#   and Trigo Platform are trademarks of Trigo Technologies, Inc.
#   All other company and product names are trademarks or registered
#   trademarks of their respective owners.
#


#
# sanitycheck/master_new.sh
#
# This file reports on existing bad data in db into STDOUT
# This file reports its progress into STDERR
#


# get src connection descriptor
. ${TOP}/src/db/schema/util/set_db.sh
. ${TOP}/bin/read_config_file.sh $TOP/etc/austin.properties
${MKDIR} ${_TRIGO_CONF_TMP_DIR}
tmpfile=${_TRIGO_CONF_TMP_DIR}sanitycheck.master.sh.out
${RM} $tmpfile

TOP_SQL="
set sqlnumber off;
set heading off;
set pagesize 0;
set linesize 10000;
set echo off;
set show off;
set feedback off;
set trimspool on;
set term off;
"

#CheckItaValueNumeric
#
# ita_value_numeric should never have Integer.MIN_VALUE Or Long.MIN_VALUE as values;
# some code critical code depends on this being true.
#
CheckItaValueNumeric() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile
    select
    count(1)
    from tctg_ita_item_attributes
    where ita_value_numeric = -9223372036854775808 or ita_value_numeric =  -2147483648;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${TR} -d " "`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] invalid ita_value_numeric entries!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for bad ita_value_numeric data" 1>/dev/null 1>&2
}


#CheckDupChi
#
# some bugs with duplicate chi rows
#
CheckDupChi() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    nvl(sum(count(1)), 0) || ' - ' || count(1)
    from tctg_chi_category_hierarchy
    where chi_next_version_id = 999999999
    group by chi_company_id, chi_parent_id, chi_child_id
    having count(1) > 1;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] chi rows that need deletion!!!!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for dupl chi entries" 1>/dev/null 1>&2
}



#CheckDupCat
#
# some bugs with duplicate cat rows
#
CheckDupCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    nvl(sum(count(1)), 0) || ' - ' || count(1)
    from tctg_cat_category
    where cat_next_version_id = 999999999
    group by cat_id
    having count(1) > 1;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] cat rows that need deletion!!!!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for dupl cat entries" 1>/dev/null 1>&2
}


#CheckDupCab
#
# some bugs with duplicate cab rows
#
CheckDupCab() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    nvl(sum(count(1)), 0) || ' - ' || count(1)
    from tctg_cab_category_attributes
    where cab_next_version_id = 999999999
    group by cab_company_id, cab_category_id, cab_node_id, cab_order, cab_row_order
    having count(1) > 1;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] cab rows that need deletion!!!!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for dupl cab entries" 1>/dev/null 1>&2
}


#CheckDupItm
#
# some bugs with duplicate itm rows
#
CheckDupItm() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    nvl(sum(count(1)), 0) || ' - ' || count(1)
    from tctg_itm_item
    where itm_next_version_id = 999999999
    group by itm_company_id, itm_container_id, itm_id
    having count(1) > 1;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] itm rows that need deletion!!!!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for dupl itm entries" 1>/dev/null 1>&2
}


#CheckDupIta
#
# some bugs with duplicate ita rows
#
CheckDupIta() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    nvl(sum(count(1)), 0) || ' - ' || count(1)
    from tctg_ita_item_attributes
    where ita_next_version_id = 999999999
    group by ita_company_id, ita_catalog_id, ita_item_id, ita_node_id, ita_order, ita_row_order
    having count(1) > 1;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] ita rows that need deletion!!!!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for dupl ita entries" 1>/dev/null 1>&2
}


#CheckDupIcm
#
# some bugs with duplicate icm rows
#
CheckDupIcm() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    nvl(sum(count(1)), 0) || ' - ' || count(1)
    from tctg_icm_item_category_map
    where icm_next_version_id = 999999999
    group by icm_company_id, icm_catalog_id, icm_cat_tree_id, icm_item_id, icm_category_id
    having count(1) > 1;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] icm rows that need deletion!!!!";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for dupl icm entries" 1>/dev/null 1>&2
}


#CheckDeadIta
#
# dead ita that refer to non existing items
#
CheckDeadIta() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from tctg_ita_item_attributes
    where ita_next_version_id = 999999999
      and not exists (select
                      1
                      from itm
                      where itm_id = ita_item_id
                      and itm_next_version_id = 999999999);
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] ita rows that refer to non existing items";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for ita rows refering to non existing items" 1>/dev/null 1>&2
}

#CheckDeadIcm
#
# dead icm that refer to non existing items
#
CheckDeadIcm() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from tctg_icm_item_category_map
    where icm_next_version_id = 999999999
      and not exists (select
                      1
                      from tctg_itm_item
                      where itm_id = icm_item_id
                        and itm_next_version_id = 999999999);
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] icm rows that refer to non existing items";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for icm rows refering to non existing items" 1>/dev/null 1>&2
}

#CheckDeadItm
#
# dead itm that refer to non existing icm
# need to do per ctr
# LKP TABLES ARE EXCLUDED because of no migration!!!
#
CheckDeadItm() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    set serveroutput on size 1000000;
    $TOP_SQL
    spool $tmpfile;
declare
count_errs number;
ctg_name varchar2(3000);
ctg_id number;
ctg_company_id number;
ctr_id number;
ctr_name varchar2(3000);

cursor ctg_row is
       select * from tctg_ctg_catalog where ctg_type = 'CATALOG';

cursor caa_row(ctg_id number) is
       select * from tctg_caa_catalog_attributes, tctg_ctr_category_tree where caa_catalog_id = ctg_id and caa_name = 'CATEGORY_TREE_ID' and caa_next_version_id = 999999999 and ctr_id = caa_value;

BEGIN
for ctg_record in ctg_row loop
    ctg_name := ctg_record.ctg_name;
    ctg_id := ctg_record.ctg_id;
    ctg_company_id := ctg_record.ctg_company_id;
    for caa_record in caa_row(ctg_id) loop
        ctr_id := caa_record.ctr_id;
        ctr_name := caa_record.ctr_name;

        --now do count of itm/icm to see if there are any missing rows
        select
        count(1) into count_errs
        from tctg_itm_item
        where itm_next_version_id = 999999999
          and itm_container_id = ctg_id  -- ctg_id from what we select earlier
        and not exists (select
                        1
                        from tctg_icm_item_category_map
                        where icm_item_id = itm_id
                          and icm_catalog_id = ctg_id  --ctg_id from where we select earlier
                          and icm_cat_tree_id = ctr_id --ctr_id from what we selected earlier
                          and icm_next_version_id = 999999999);

        if (count_errs > 0) then
        begin
                dbms_output.put_line(count_errs || ' itms with no icms found for ctg_id = [' || ctg_id || '] ctg_name = [' || ctg_name || '] ctr_id = [' || ctr_id || '] ctr_name = [' || ctr_name || ']  !!!!!');
        end;
        end if;
    end loop;
end loop;
end;
/
    spool off;
EOF
    txt=`cat $tmpfile | grep -v 'SQL'`
    if [ "$txt" != "" ]; then
        ${ECHO} "$txt";
    fi
    ${RM} $tmpfile
    ${ECHO} "done with test for itm rows refering to non existing icms" 1>/dev/null 1>&2
}

#CheckDuplicateNodeOrder
#
#  Two nodes in a given spec should NOT have the same order
#

CheckDuplicateNodeOrder() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
      nvl(sum(count(1)), 0) || ' - ' || count(1)
    from tctg_noh_node_hierarchy
    where noh_next_version_id = 999999999
    group by noh_spec_id, noh_order
    having count(*) > 1;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] noh rows with duplicate orders.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for multiple Nodes with same order" 1>/dev/null 1>&2
}


#CheckNodeAttributes
#
#  NOA table should NOT have more than one entry of the folling for a given Node.
#  The code depends on getting a single row back.
#        case SchemaFacetEnum.CATEGORY_DELIMITER:
#

CheckNodeAttributes() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    nvl(sum(count(1)), 0) || ' - ' || count(1)
    from tctg_noa_node_attributes
    where noa_next_version_id = 999999999
    and noa_name in ('DATE_FORMAT', 'DEFAULT_VALUE', 'LOOKUP_TABLE', 'MINLENGTH', 'PATTERN', 'SEQUENCE_INCREMENT', 'SEQUENCE_START', 'STRING_ENUMERATION_RULE', 'VALIDATION_RULE', 'VALUE_RULE', 'MIN_OCCURRENCE', 'MAX_OCCURRENCE', 'TYPE', 'MAXLENGTH')
    group by noa_spec_id, noa_node_id, noa_name
    having count(*) > 1;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] noa rows for Single Valued Attributes.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for multiple Node Attributes" 1>/dev/null 1>&2
}



#CheckNodeHierarchy
#
#  All nodes in the NOH table should have the entry in the NOD table.
#

CheckNodeHierarchy() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from tctg_noh_node_hierarchy
    where noh_next_version_id = 999999999
    and not exists
    (select 1
      from nod
      where noh_child_node_id = nod_id
            and noh_next_version_id = 999999999);
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] noh rows for a spec which are not in NOD.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for bad NOH data" 1>/dev/null 1>&2
}


#CheckCfpCat
#
# ROWS IN CFP NOT IN CAT 

CheckCfpCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from cfp where cfp_category_id  not in 
    (select distinct cat_id 
    from cat 
    where cat_next_version_id = 999999999) 
    and cfp_next_version_id=999999999;
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CFP rows which are not in CAT.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CFP data not in CAT" 1>/dev/null 1>&2
}


#CheckCsmCat
#
# ROWS IN CSM NOT IN CAT
#

CheckCsmCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from csm where csm_category_id in 
    (select cfp_category_id 
    from cfp 
    where cfp_category_id  not in 
        (select distinct cat_id 
        from cat 
        where cat_next_version_id = 999999999) 
        and cfp_next_version_id=999999999);
    spool off;
    
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CSM rows which are not in CAT.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CSM data not in CAT" 1>/dev/null 1>&2
}


#CheckCsaCat
#
# ROWS IN CSA NOT IN CAT
#

CheckCsaCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from csa where csa_category_id in 
        (select cfp_category_id 
        from cfp 
        where cfp_category_id  not in 
            (select distinct cat_id 
            from cat 
            where cat_next_version_id = 999999999) 
        and cfp_next_version_id=999999999);
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CSA rows which are not in CAT.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CSA data not in CAT" 1>/dev/null 1>&2
}


#CheckChiParentCat
#
# PARENT ROWS IN CHI NOT IN CAT
#

CheckChiParentCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from chi where chi_parent_id in 
        (select cfp_category_id 
        from cfp 
        where cfp_category_id  not in 
            (select distinct cat_id 
            from cat 
            where cat_next_version_id = 999999999) 
            and cfp_next_version_id=999999999);
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CHI parent rows which are not in CAT.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CHI parent data not in CAT" 1>/dev/null 1>&2
}

#CheckChiChildCat
#
# CHILD ROWS IN CHI NOT IN CAT

CheckChiChildCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from chi where chi_child_id in 
        (select cfp_category_id 
        from cfp 
        where cfp_category_id  not in 
            (select distinct cat_id 
            from cat 
            where cat_next_version_id = 999999999) 
        and cfp_next_version_id=999999999);
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CHI child rows which are not in CAT.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CHI child data not in CAT" 1>/dev/null 1>&2
}


#CheckCcmSourceCat
#
# SOURCE ROWS IN CCM NOT IN CAT
#

CheckCcmSourceCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from ccm where ccm_src_category_id in 
        (select cfp_category_id 
        from cfp 
        where cfp_category_id  not in 
            (select distinct cat_id 
            from cat 
            where cat_next_version_id = 999999999) 
            and cfp_next_version_id=999999999);

    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CCM source rows which are not in CAT.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CCM source data not in CAT" 1>/dev/null 1>&2
}


#CheckCcmDestCat
#
# DESTINATION ROWS IN CCM NOT IN CAT
#

CheckCcmDestCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from ccm where ccm_dst_category_id in 
        (select cfp_category_id 
        from cfp 
        where cfp_category_id  not in 
            (select distinct cat_id 
            from cat 
            where cat_next_version_id = 999999999) 
        and cfp_next_version_id=999999999);
        
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CCM destination rows which are not in CAT.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CCM destination data not in CAT" 1>/dev/null 1>&2
}


#CheckIcmCat
#
# ROWS IN ICM NOT IN CAT

CheckIcmCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from icm where icm_category_id in 
        (select cfp_category_id 
        from cfp 
        where cfp_category_id  not in 
            (select distinct cat_id 
            from cat 
            where cat_next_version_id = 999999999) 
            and cfp_next_version_id=999999999);

    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] ICM rows which are not in CAT.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for ICM data not in CAT" 1>/dev/null 1>&2
}


#CheckCatCfp
#
# ROWS IN CAT NOT IN CFP
# 

CheckCatCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from cat
    where cat_id  not in 
        (select distinct cfp_category_id 
        from cfp 
        where cfp_next_version_id = 999999999) 
    and cat_next_version_id=999999999;
    
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CAT rows which are not in CFP.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CAT data not in CFP" 1>/dev/null 1>&2
}


#CheckCsmCfp
#
# ROWS IN CSM NOT IN CFP
# 

CheckCsmCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from csm where csm_category_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
        and cat_next_version_id=999999999);
spool off;

EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CSM rows which are not in CFP.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CSM data not in CFP" 1>/dev/null 1>&2
}


#CheckCsaCfp
#
# ROWS IN CSA NOT IN CFP
# 

CheckCsaCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from csa where csa_category_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
        and cat_next_version_id=999999999);
    
    spool off;
EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CSA rows which are not in CFP.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CSA data not in CFP" 1>/dev/null 1>&2
}


#CheckChiParentCfp
#
# PARENT ROWS IN CHI NOT IN CFP
# 

CheckChiParentCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from chi where chi_parent_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
            and cat_next_version_id=999999999);
spool off;

EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CHI Parent rows which are not in CFP.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CHI Parent data not in CFP" 1>/dev/null 1>&2
}

#CheckChiChildCfp
#
# CHILD ROWS IN CHI NOT IN CFP
# 

CheckChiChildCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from chi where chi_child_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
        and cat_next_version_id=999999999);
        
spool off;

EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CHI Child rows which are not in CFP.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CHI Child data not in CFP" 1>/dev/null 1>&2
}


#CheckCcmSourceCfp
#
# SRC ROWS IN CCM NOT IN CFP
# 

CheckCcmSourceCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from ccm where ccm_src_category_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
            and cat_next_version_id=999999999);
spool off;

EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CCM Source rows which are not in CFP.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CCM Source data not in CFP" 1>/dev/null 1>&2
}



#CheckCcmDestCfp
#
# DEST ROWS IN CCM NOT IN CFP
# 

CheckCcmDestCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from ccm where ccm_dst_category_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
        and cat_next_version_id=999999999);

spool off;

EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] CCM Destination rows which are not in CFP.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for CCM Destination data not in CFP" 1>/dev/null 1>&2
}


#CheckIcmCfp
#
# ROWS IN ICM NOT IN CFP
# 

CheckIcmCfp() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1)
    from icm where icm_category_id in 
        (select cat_id
        from cat
        where cat_id  not in 
            (select distinct cfp_category_id 
            from cfp 
            where cfp_next_version_id = 999999999) 
            and cat_next_version_id=999999999);
            
spool off;

EOF
    cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
    if [ "$cnt" != "0" ]; then
        ${ECHO} "Found [$cnt] ICM rows which are not in CFP.";
    fi
    ${RM} $tmpfile
    ${ECHO} "Done with the test for ICM data not in CFP" 1>/dev/null 1>&2
}

#CheckCat
#
# Check to see if Category tables exist
#

CheckCat() {
    ${TRIGO_SQLPLUS} ${CONNECTION} <<EOF >& /dev/null
    $TOP_SQL
    spool $tmpfile;
    select
    count(1) from user_tables where table_name = 'TCTG_CFP_CAT_FULL_PATHS';

spool off;

EOF
cnt=`${CAT} $tmpfile | ${GREP} -v 'SQL'| ${BC}`
if [ "$cnt" != "0" ]; then
CheckCfpCat
CheckCsmCat
CheckCsaCat
CheckChiParentCat
CheckChiChildCat
CheckCcmSourceCat
CheckCcmDestCat
CheckIcmCat
CheckCatCfp
CheckCsmCfp
CheckCsaCfp
CheckChiParentCfp
CheckChiChildCfp
CheckCcmSourceCfp
CheckCcmDestCfp
CheckIcmCfp
fi
    ${RM} $tmpfile
}

#
# Main
#

CheckItaValueNumeric
CheckDupChi
CheckDupCat
CheckDupCab
CheckDupItm
CheckDupIta
CheckDupIcm
CheckDeadIta
CheckDeadIcm
CheckDeadItm
CheckDuplicateNodeOrder
CheckNodeAttributes
CheckNodeHierarchy
CheckCat

